<h1 align="center">
  <br>
  <a href="https://openpecha.org"><img src="https://avatars.githubusercontent.com/u/82142807?s=400&u=19e108a15566f3a1449bafb03b8dd706a72aebcd&v=4" alt="OpenPecha" width="150"></a>
  <br>
</h1>

<h3 align="center">Pedurma</h3>


<!-- Replace the title of the repository -->

<p align="center">
  <a href="#description">Description</a> •
  <a href="#owner">Owner</a> •
  <a href="#integrations">Integrations</a> •
  <a href="#docs">Docs</a>
</p>
<hr>


## Description

Pip package to reconstruct pedurma text.

<!-- This section provides a high-level overview for the repo -->

## Owner

- [@ngawangtrinley](https://github.com/ngawangtrinley)
- [@kaldan7](https://github.com/kaldan7)


<!-- This section lists the owners of the repo -->

## Integrations

- No integrations with other repos.

<!-- This section must list as bulleted list how this repo depends or is integrated with other repos -->

## Docs

No documentations.

<!-- This section must link to the docs which are in the root of the repository in /docs -->


